# Part of the A-A-P recipe executive 

# Copyright (c) 2002-2003 Lars Ivar Igesund and stichting NLnet Labs
# Permission to copy and use this file is specified in the file COPYING.
# If this file is missing you can find it here: http://www.a-a-p.org/COPYING

#
# This module sets up variables and actions for using the DMD compiler tools.
#

from RecPython import *
import Global
from Action import action_add
from Dictlist import str2dictlist
from RecPos import RecPos


def exists():
    """
    Return TRUE when the DMD toolchain can be found.
    """
    return program_path("dmd")


def define_actions():
    """
    Define the actions that DMD can accomplish.
    """
    rd = Global.globals
    rpstack = [ RecPos("compile_dmd d action") ]
    action_add(rpstack, rd, str2dictlist(rpstack, "compile_dmd object,dllobject,libobject d"),
            "opt =\n"
            "@if _no.OPTIMIZE and int(_no.OPTIMIZE) > 0:\n"
            "  opt = -O\n"
            "dbg =\n"
            "DEBUG ?=\n"
            "@if _no.DEBUG == 'yes':\n"
            "  dbg = -g\n"
            ":sys $DMD $?DFLAGS $?DVERSION $opt $dbg $?DDEBUG $?DIMPORT -of$target -c $source")
    rpstack = [ RecPos("build_dmd action") ]
    action_add(rpstack, rd, str2dictlist(rpstack, "build_dmd object,dllobject,libobject"),
            ":sys $DMD $?DLINKFLAGS -of$target $source")
    
    if not rd["_top"].get("DMD"):
        rd["_top"]["DMD"] = "dmd"


def use_actions(scope):
    """
    Setup variables so that the default actions use the DMD actions.
    """
    scope["D_COMPILE_ACTION"] = "compile_dmd"
    scope["D_BUILD_ACTION"] = "build_dmd"

# vim: set sw=4 et sts=4 tw=79 fo+=l:
