# Part of the A-A-P recipe executive: Setup using MSVC

# Copyright (c) 2002-2003 stichting NLnet Labs
# Permission to copy and use this file is specified in the file COPYING.
# If this file is missing you can find it here: http://www.a-a-p.org/COPYING

#
# This module sets up variables and actions for using the Microsoft Visual C
# compiler tools.
#

from RecPython import *
import Global
from Action import action_add
from Dictlist import str2dictlist
from RecPos import RecPos


def exists():
    """
    Return TRUE when the MSVC toolchain can be found.
    """
    return program_path("cl") or program_path("vcvars32")


def define_actions():
    """
    Define the actions that MSVC can accomplish.
    """
    rd = Global.globals

    cmd = ("defi = $?DEFINE\n"
            + "@defi = re.sub('-D', '/D', defi)\n"
            + "incl = $?INCLUDE\n"
            + "@incl = re.sub('-I', '/I', incl)\n")

    # TODO: use DEBUG and OPTIMIZE
    rpstack = [ RecPos("compile_msvc c action") ]
    action_add(rpstack, rd, str2dictlist(rpstack, "compile_msvc object c"),
            cmd + ":sys $MSVC $CPPFLAGS $defi $incl $CFLAGS /c $source /Fo$target")

    rpstack = [ RecPos("compile_msvc cpp action") ]
    action_add(rpstack, rd, str2dictlist(rpstack, "compile_msvc object cpp"),
            cmd + ":sys $MSVC $CPPFLAGS $defi $incl $CXXFLAGS /TP /c $source /Fo$target")

    if not rd.get("MSVC"):
        rd["MSVC"] = "cl"

    rpstack = [ RecPos("build_msvc action") ]
    action_add(rpstack, rd, str2dictlist(rpstack, "build_msvc object"),
            ":sys $MSLINK $LINKFLAGS /out:$target $source")
    if not rd.get("MSLINK"):
        rd["MSLINK"] = "link"
    if not rd.get("LINKFLAGS"):
        rd["LINKFLAGS"] = "/nologo"


def use_actions(scope):
    """
    Setup variables so that the default actions use the MSVC actions.
    """
    scope["C_COMPILE_ACTION"] = "compile_msvc"
    scope["CXX_COMPILE_ACTION"] = "compile_msvc"
    scope["C_BUILD_ACTION"] = "build_msvc"
    scope["CXX_BUILD_ACTION"] = "build_msvc"

# vim: set sw=4 et sts=4 tw=79 fo+=l:
